import ReactDOM from 'react-dom';
import { configureStore } from "@reduxjs/toolkit";
import {Provider} from 'react-redux';
import {BrowserRouter} from 'react-router-dom';
import "./index.css";

import App from './App';
import usersReduser from './store/reducers/usersReducer';

const localstorageMiddleware = ({getState}) => (next) => (action) => {
  const result = next(action);
  localStorage.setItem("user", JSON.stringify(getState().users.user));
  return result;
}

const loadFromLocalStorage = () => {
  if (localStorage.getItem("user") !== null) {
    return {users: {user: JSON.parse(localStorage.getItem("user"))}}
  }
  return undefined;
}


const store = configureStore({
  reducer: {
    users: usersReduser
},
  preloadedState: loadFromLocalStorage(),
  middleware: (getDefaultMiddleware) => getDefaultMiddleware().concat(localstorageMiddleware)
});

const app = (
  <BrowserRouter>
  <Provider store={store}>
      <App/>
  </Provider>
  </BrowserRouter>
);

const root = ReactDOM.createRoot(document.getElementById('root'));
root.render(app);